@@ -9,6 +9,8 @@ possible, however lossy it might be
 # Copyright 2012-2014 Anthony Beville
 # Copyright 2020 Brian Pepple
 
+from dataclasses import dataclass, field
+from datetime import date
 from typing import List, Optional, Tuple, TypedDict
 
 from .utils import list_to_string
@@ -44,58 +46,77 @@ class ImageMetadata(TypedDict, total=False):
     ImageWidth: str
 
 
-class CreditMetadata(TypedDict):
+@dataclass
+class CreditMetadata:
     person: str
     role: str
     primary: bool
 
 
+@dataclass
+class SeriesMetadata:
+    name: str
+    sort_name: Optional[str] = None
+    type: Optional[str] = None
+
+
+@dataclass
+class InfoSourceMetadata:
+    source: str
+    id: int
+
+
+@dataclass
 class GenericMetadata:
-    def __init__(self) -> None:
+    is_empty: bool = True
+    tag_origin: Optional[str] = None
 
-        self.is_empty: bool = True
-        self.tag_origin: Optional[str] = None
+    info_source: Optional[InfoSourceMetadata] = None
+    series: Optional[SeriesMetadata] = None
+    issue: Optional[str] = None
+    stories: List[str] = field(default_factory=list)
+    publisher: Optional[str] = None
+    cover_date: Optional[date] = None
+    store_date: Optional[date] = None
+    issue_count: Optional[int] = None
+    volume: Optional[int] = None
+    genres: List[str] = field(default_factory=list)
+    language: Optional[str] = None  # 2 letter iso code
+    comments: Optional[str] = None  # use same way as Summary in CIX
 
-        self.series: Optional[str] = None
-        self.issue: Optional[str] = None
-        self.title: Optional[str] = None
-        self.publisher: Optional[str] = None
-        self.month: Optional[int] = None
-        self.year: Optional[int] = None
-        self.day: Optional[int] = None
-        self.issue_count: Optional[int] = None
-        self.volume: Optional[int] = None
-        self.genre: Optional[str] = None
-        self.language: Optional[str] = None  # 2 letter iso code
-        self.comments: Optional[str] = None  # use same way as Summary in CIX
+    volume_count: Optional[str] = None
+    critical_rating: Optional[str] = None
+    country: Optional[str] = None
 
-        self.volume_count: Optional[str] = None
-        self.critical_rating: Optional[str] = None
-        self.country: Optional[str] = None
+    alternate_series: Optional[str] = None
+    alternate_number: Optional[str] = None
+    alternate_count: Optional[int] = None
+    imprint: Optional[str] = None
+    notes: Optional[str] = None
+    web_link: Optional[str] = None
+    format: Optional[str] = None
+    manga: Optional[str] = None
+    black_and_white: Optional[bool] = None
+    page_count: Optional[int] = None
+    age_rating: Optional[str] = None
 
-        self.alternate_series: Optional[str] = None
-        self.alternate_number: Optional[str] = None
-        self.alternate_count: Optional[int] = None
-        self.imprint: Optional[str] = None
-        self.notes: Optional[str] = None
-        self.web_link: Optional[str] = None
-        self.format: Optional[str] = None
-        self.manga: Optional[str] = None
-        self.black_and_white: Optional[bool] = None
-        self.page_count: Optional[int] = None
-        self.maturity_rating: Optional[str] = None
+    story_arcs: List[str] = field(default_factory=list)
+    series_group: Optional[str] = None
+    scan_info: Optional[str] = None
 
-        self.story_arc: Optional[str] = None
-        self.series_group: Optional[str] = None
-        self.scan_info: Optional[str] = None
+    characters: List[str] = field(default_factory=list)
+    teams: List[str] = field(default_factory=list)
+    locations: List[str] = field(default_factory=list)
 
-        self.characters: Optional[str] = None
-        self.teams: Optional[str] = None
-        self.locations: Optional[str] = None
+    credits: List[CreditMetadata] = field(default_factory=list)
+    tags: List[str] = field(default_factory=list)
+    pages: List[ImageMetadata] = field(default_factory=list)
 
-        self.credits: List[CreditMetadata] = []
-        self.tags: List[str] = []
-        self.pages: List[ImageMetadata] = []
+    def __post_init__(self):
+        for key, value in self.__dict__.items():
+            if value and key != "is_empty":
+                self.is_empty = False
+                break
 
     def overlay(self, new_md: "GenericMetadata") -> None:
         """Overlay a metadata object on this one
@@ -115,16 +136,18 @@ class GenericMetadata:
             self.is_empty = False
 
         assign("series", new_md.series)
+        assign("info_source", new_md.info_source)
         assign("issue", new_md.issue)
         assign("issue_count", new_md.issue_count)
-        assign("title", new_md.title)
+        if len(new_md.stories) > 0:
+            assign("stories", new_md.stories)
         assign("publisher", new_md.publisher)
-        assign("day", new_md.day)
-        assign("month", new_md.month)
-        assign("year", new_md.year)
+        assign("cover_date", new_md.cover_date)
+        assign("store_date", new_md.store_date)
         assign("volume", new_md.volume)
         assign("volume_count", new_md.volume_count)
-        assign("genre", new_md.genre)
+        if len(new_md.genres) > 0:
+            assign("genre", new_md.genres)
         assign("language", new_md.language)
         assign("country", new_md.country)
         assign("critical_rating", new_md.critical_rating)
@@ -136,23 +159,22 @@ class GenericMetadata:
         assign("format", new_md.format)
         assign("manga", new_md.manga)
         assign("black_and_white", new_md.black_and_white)
-        assign("maturity_rating", new_md.maturity_rating)
-        assign("story_arc", new_md.story_arc)
+        assign("age_rating", new_md.age_rating)
+        if len(new_md.story_arcs) > 0:
+            assign("story_arcs", new_md.story_arcs)
         assign("series_group", new_md.series_group)
         assign("scan_info", new_md.scan_info)
-        assign("characters", new_md.characters)
-        assign("teams", new_md.teams)
-        assign("locations", new_md.locations)
+        if len(new_md.characters) > 0:
+            assign("characters", new_md.characters)
+        if len(new_md.teams) > 0:
+            assign("teams", new_md.teams)
+        if len(new_md.locations) > 0:
+            assign("locations", new_md.locations)
         assign("comments", new_md.comments)
         assign("notes", new_md.notes)
 
         self.overlay_credits(new_md.credits)
 
-        # TODO
-
-        # not sure if the tags and pages should broken down, or treated
-        # as whole lists....
-
         # For now, go the easy route, where any overlay
         # value wipes out the whole list
         if len(new_md.tags) > 0:
@@ -215,6 +237,7 @@ class GenericMetadata:
 
     def __str__(self) -> str:
         vals: List[Tuple[str, str]] = []
+
         if self.is_empty:
             return "No metadata"
 
@@ -228,14 +251,15 @@ class GenericMetadata:
         add_attr_string("series")
         add_attr_string("issue")
         add_attr_string("issue_count")
-        add_attr_string("title")
+        if self.stories:
+            add_attr_string("stories")
         add_attr_string("publisher")
-        add_attr_string("year")
-        add_attr_string("month")
-        add_attr_string("day")
+        add_attr_string("cover_date")
+        add_attr_string("store_date")
         add_attr_string("volume")
         add_attr_string("volume_count")
-        add_attr_string("genre")
+        if self.genres:
+            add_attr_string("genres")
         add_attr_string("language")
         add_attr_string("country")
         add_attr_string("critical_rating")
@@ -249,13 +273,17 @@ class GenericMetadata:
 
         if self.black_and_white:
             add_attr_string("black_and_white")
-        add_attr_string("maturity_rating")
-        add_attr_string("story_arc")
+        add_attr_string("age_rating")
+        if self.story_arcs:
+            add_attr_string("story_arcs")
         add_attr_string("series_group")
         add_attr_string("scan_info")
-        add_attr_string("characters")
-        add_attr_string("teams")
-        add_attr_string("locations")
+        if self.characters:
+            add_attr_string("characters")
+        if self.teams:
+            add_attr_string("teams")
+        if self.locations:
+            add_attr_string("locations")
         add_attr_string("comments")
         add_attr_string("notes")
 
